Name:           slic3r
Version:        1.2.9
Release:        %mkrel 7
Summary:        G-code generator for 3D printers (RepRap, Makerbot, Ultimaker etc.)
License:        AGPLv3
# Images are CC-BY, code is AGPLv3
Group:          Sciences/Other
URL:            http://slic3r.org/
#The download URL is https://github.com/alexrj/Slic3r/archive/%%{version}.tar.gz, but the file
# comes down with the traditional tarball naming convention
Source0:        Slic3r-%{version}.tar.gz

# Modify Build.PL so we are able to build this on Fedora
Patch0:         %{name}-buildpl.patch

# Use /usr/share/slic3r as datadir
Patch1:         %{name}-datadir.patch
Patch2:         %{name}-english-locale.patch
Patch3:         %{name}-linker.patch
Patch4:         %{name}-1.2.4-fdr-mga-clipper.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=1306668
# https://github.com/alexrj/Slic3r/issues/3117#issuecomment-187767676
Patch5:         %{name}-boost160.patch

# Patch to manually cast too bool, fix FTBFS
# Will report upstream
Patch6:         %{name}-boolcast.patch


Source1:        %{name}.desktop
Source2:        %{name}.appdata.xml

BuildRequires:  perl-devel
BuildRequires:  perl(Class::XSAccessor)
BuildRequires:  perl(Encode::Locale) >= 1.05
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.80
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.22
BuildRequires:  perl(ExtUtils::Typemaps::Default) >= 1.50.0
BuildRequires:  perl(ExtUtils::Typemaps) >= 1.00
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Growl::GNTP) >= 0.15
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(List::Util)
BuildRequires:  perl(Math::PlanePath) >= 53
BuildRequires:  perl(Module::Build::WithXSpp) >= 0.14
BuildRequires:  perl(Moo) >= 1.6.0
BuildRequires:  perl(parent)
BuildRequires:  perl(Scalar::Util)
BuildRequires:  perl(Storable)
BuildRequires:  perl(SVG)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Time::HiRes)
BuildRequires:  perl(Wx)
BuildRequires:  perl(XML::SAX)
BuildRequires:  perl(XML::SAX::ExpatXS)

BuildRequires:  admesh-devel >= 0.98.1
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  poly2tri-devel
BuildRequires:  polyclipping-devel >= 6.2.0
BuildRequires:  ImageMagick

Requires:       perl(XML::SAX)
Requires:       perl(threads) >= %perl_convert_version 1.96
#This duplicate added, because otherwise RPM is resolving 1.92 as meeting the 1.96+ requirement
Requires:       perl-threads >= %perl_convert_version 1.96

Provides:       %{name} = %{version}
Obsoletes:      %{name}-stable
Obsoletes:      %{name}-experimental

%description
Slic3r is a G-code generator for 3D printers. It's compatible with RepRaps,
Makerbots, Ultimakers and many more machines.
See the project homepage at slic3r.org and the documentation on the Slic3r wiki
for more information.

%prep
%setup -qn Slic3r-%{version}
%autopatch -p1

# Remove bundled admesh, clipper, poly2tri and boost
rm -rf xs/src/admesh
rm xs/src/clipper.*pp
rm -rf xs/src/poly2tri
rm -rf xs/src/boost

%build
cd xs
perl ./Build.PL installdirs=vendor optimize="$RPM_OPT_FLAGS"
./Build
cd -
# Building non XS part only runs test, so skip it and run it in tests

# prepare pngs in mutliple sizes
for res in 16 32 48 128 256; do
  mkdir -p hicolor/${res}x${res}/apps
done
cd hicolor
convert ../var/Slic3r.ico %{name}.png
cp %{name}-0.png 256x256/apps/%{name}.png
cp %{name}-1.png 128x128/apps/%{name}.png
cp %{name}-2.png 48x48/apps/%{name}.png
cp %{name}-3.png 32x32/apps/%{name}.png
cp %{name}-4.png 16x16/apps/%{name}.png
rm %{name}-*.png
cd -

# To avoid "iCCP: Not recognized known sRGB profile that has been edited"
cd var
find . -type f -name "*.png" -exec convert {} -strip {} \;
cd -

%install
cd xs
./Build install destdir=%{buildroot} create_packlist=0
cd -
find %{buildroot} -type f -name '*.bs' -size 0 -exec rm -f {} \;

# I see no way of installing slic3r with it's build script
# So I copy the files around manually
mkdir -p  %{buildroot}%{_bindir}
mkdir -p  %{buildroot}%{perl_vendorlib}
mkdir -p  %{buildroot}%{_datadir}/%{name}
mkdir -p  %{buildroot}%{_datadir}/icons
mkdir -p  %{buildroot}%{_datadir}/appdata

cp -a %{name}.pl %{buildroot}%{_bindir}/%{name}
cp -ar lib/* %{buildroot}%{perl_vendorlib}

cp -a var/* %{buildroot}%{_datadir}/%{name}
cp -r hicolor %{buildroot}%{_datadir}/icons
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

cp %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%{_fixperms} %{buildroot}*

%check
# disable testsuite:
exit 0
cd xs
./Build test verbose=1 || :
cd -
SLIC3R_NO_AUTO=1 %__perl Build.PL installdirs=vendor
# the --gui runs no tests, it only checks requires

%files
%doc README.md
%{_bindir}/%{name}
%{perl_vendorlib}/Slic3r*
%{perl_vendorarch}/Slic3r*
%{perl_vendorarch}/auto/Slic3r*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/%{name}


%changelog
* Mon Sep 19 2016 akien <akien> 1.2.9-7.mga6
+ Revision: 1054420
- Rebuild again for polyclipping, for real this time
- Rebuild for polyclipping 6.4
- Remove Fedoraisms

* Sun Jun 19 2016 pterjan <pterjan> 1.2.9-5.mga6
+ Revision: 1036487
- Rebuild for perl 5.22.2

* Sun Apr 24 2016 akien <akien> 1.2.9-4.mga6
+ Revision: 1005879
- Rebuild for new poly2tri

* Tue Mar 29 2016 tv <tv> 1.2.9-3.mga6
+ Revision: 996067
- sync patch 1 with FC
- add build fix from FC
- obsoletes both slic3r-stable & slic3r-experimental
- rename slic3r-stable as slic3r in SVN

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sun Jun 28 2015 tv <tv> 1.2.9-1.mga6
+ Revision: 846680
- disable testsuite
- BR perl(Encode::Locale)
- ignore testsuite faillure (like for experimental)
- new release
- 1.2.x is now stable
- rebuild for soname-ifed perl

* Tue Jun 23 2015 sander85 <sander85> 1.1.7-5.mga6
+ Revision: 840870
- Rebuild for perl 5.22

* Tue Jan 13 2015 shlomif <shlomif> 1.1.7-4.mga5
+ Revision: 810322
- Add missing BR on perl-devel
- Importing slic3r-stable (thanks to Richard Houser)

